@@ -13,11 +13,9 @@
 import mock
 import munch
 
-from heatclient import client as heat_client
 from neutronclient.common import exceptions as n_exc
 import testtools
 
-from os_client_config import cloud_config
 import shade
 from shade import _utils
 from shade import exc
@@ -74,19 +72,6 @@ class TestShade(base.TestCase):
         self.assertRaises(exc.OpenStackCloudException,
                           self.cloud.list_servers)
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session')
-    @mock.patch.object(cloud_config.CloudConfig, 'get_legacy_client')
-    def test_heat_args(self, get_legacy_client_mock, get_session_mock):
-        session_mock = mock.Mock()
-        get_session_mock.return_value = session_mock
-        self.cloud.heat_client
-        get_legacy_client_mock.assert_called_once_with(
-            service_key='orchestration',
-            client_class=heat_client.Client,
-            interface_key=None,
-            pass_version_arg=True,
-        )
-
     @mock.patch.object(shade.OpenStackCloud, 'neutron_client')
     def test_list_networks(self, mock_neutron):
         net1 = {'id': '1', 'name': 'net1'}
